@@ -9,7 +9,7 @@ def fetch_relational_data(fields,
                           column_name,
                           compair_operator,
                           column_values, functions=None):
-    app = WeDeliverCore.getApp()
+    app = WeDeliverCore.get_app()
     db = app.extensions['sqlalchemy'].db
 
     relational_data_result = []
