@@ -7,6 +7,8 @@ import json
 
 from wedeliver_core.helpers.get_obj_value import get_obj_value
 
+from wedeliver_core.helpers.service_config import ServiceConfig
+
 
 class MicroFetcher(object):
     base_data = None
@@ -23,12 +25,24 @@ class MicroFetcher(object):
     module_name = None
     function_params = None
 
-    def __init__(self, service_name):
-        self.app = WeDeliverCore.getApp()
-        self.service_url = self.app.config.get(service_name)
+    def __init__(self, service):
+        self.app = WeDeliverCore.get_app()
+
+        if isinstance(service, ServiceConfig):
+            service  = service.initialize()
+            service_name = service.name
+            service_url = service.url
+        else:
+            service_name = service
+            service_url = None
+
+        env_service_url = self.app.config.get(service_name)
+
+        self.service_url = env_service_url if env_service_url else service_url
+
         self.service_name = service_name
         if not self.service_url:
-            raise AppMicroFetcherError('Service {} not defined on Env'.format(self.service_url))
+            raise AppMicroFetcherError('Service {} not defined on Env or in ServiceConfig'.format(self.service_url))
 
     def join(self, base_data, output_key=None):
         self.base_data = base_data
